SharkPlayer

Struct SharkPlayer 

pub struct SharkPlayer<'a, P: ControlsIconProvider = DefaultControlsIconProvider> { /* private fields */ }
The video player widget. This is what actually get’s created in the ui function.

Implementations

Source

impl<'a> SharkPlayer<'a>

pub fn new(backend: &'a mut PlayerState) -> Self

Create a new SharkPlayer. To use a custom icons provider, see SharkPlayer::new_with_icons.

Source

impl<'a, P: ControlsIconProvider> SharkPlayer<'a, P>

pub fn new_with_icons(backend: &'a mut PlayerState, icons: P) -> Self

Create a new SharkPlayer using the provied ControlsIconProvider.

pub fn keybindings(self, keybindings: Keybinds) -> Self

pub fn animations(self, show: bool) -> Self

Whether to use animations.

pub fn controls_timeout(self, timeout: Duration) -> Self

Set how long to wait for pointer movement before hiding the controls.

pub fn sizing(self, sizing: Sizing) -> Self

Constrain player size.

pub fn bar_height(self, height: f32) -> Self

Set the control bar height.

pub fn skip_seconds(self, seconds: f64) -> Self

Set how many seconds the skip buttons seek by.

pub fn background_color(self, color: Color32) -> Self

pub fn default_info_width(self, width: f32) -> Self

pub fn error_callback(self, f: Rc<dyn Fn(Error)>) -> Self